@@ -19,7 +19,7 @@ class FWA(Optimizer):
         """Initialization"""
         Optimizer.__init__(self)
 
-        self.X = None
+        # self.X = None # seems to be obsolete
         self.X0 = None
         self.cX = None
         self.method = 'Vanilla'
